/**
 *
 * Copyright (c) 2000 Justin E. Forrester (forrestje@bigfoot.com)
 * All Rights Reserved
 * 
 * I provide the Windows "Fuzz" Testing Tool on an AS IS basis, and
 * do not warrant its validity or performance.  I reserve the right
 * to update, modify, or discontinue this software at any time.  I
 * shall have no obligation to supply such updates or modifications or
 * any other form of support to you.
 * 
 * This license is for research uses.  For such uses, there is no
 * charge. I define "research use" to mean you may freely use it
 * inside your organization for whatever purposes you see fit. But you
 * may not re-distribute Fuzz or parts of Fuzz, in any form
 * source or binary (including derivatives), electronic or otherwise,
 * to any other organization or entity without my permission. For
 * other uses, please contact me at forrestje@bigfoot.com. 
 * 
 * All warranties, including without limitation, any warranty of
 * merchantability or fitness for a particular purpose, are hereby
 * excluded.
 * 
 * By your use of Fuzz, you understand and agree that I (or any
 * other person or entity with proprietary rights in Fuzz) am
 * under no obligation to provide either maintenance services,
 * update services, notices of latent defects, or correction of
 * defects for Fuzz.
 * 
 * Even if advised of the possibility of such damages, under no
 * circumstances shall I (or any other person or entity with
 * proprietary rights in the software licensed hereunder) be liable
 * to you or any third party for direct, indirect, or consequential
 * damages of any character regardless of type of action, including,
 * without limitation, loss of profits, loss of use, loss of good
 * will, or computer failure or malfunction.  You agree to indemnify
 * me (and any other person or entity with proprietary rights in the
 * software licensed hereunder) for any and all liability it may
 * incur to third parties resulting from your use of Fuzz.
 *
 **/

#ifndef WINDOW_LIST_H_INCLUDED
#define WINDOW_LIST_H_INCLUDED

#include <windows.h>

//=============================================================================
// Support classes
//     These classes basically implement a simple linked list 
//     Yes, I could have used MFC collection classes, but I did not want to 
//     have to rely on MFC for this simple app.  
//=============================================================================

// Max length of strings
#define CAPTIONLENGTH  32
#define WNDCLASSLENGTH 32

//=============================================================================
// WindowSpec - individual window specifiers
//=============================================================================
class WindowSpec
{
public:
    friend class WindowList;
    WindowSpec(VOID);
    ~WindowSpec(VOID);
    HWND hWnd;
    LPSTR pszCaption;
    LPSTR pszWndClassName;
    RECT rect;
    WindowSpec *pNext;
};


//=============================================================================
// WindowList - main class that will hold the window class
//=============================================================================
class WindowList
{
public:
    WindowList(VOID);
    ~WindowList(VOID);

    // get current number of windows associated with this process
    LONG numWindows(VOID);

    // generate the list of top level windows associated with this process
    VOID genWindowList(DWORD dwProcessId);

    // helper function for genWindowList
    static BOOL CALLBACK enumWindowsCallback(HWND hwnd, LPARAM lParam);

    // get a specific window in the list
    WindowSpec *getWindowAt(LONG nIndex);
protected:
    static LONG nNumWindows;
    static WindowSpec *pWindowSpecs;
};

#endif

